@@ -15,7 +15,7 @@
 
 #include "common.h"
 
-#ifdef HAVE_RPC_RPC_H
+#ifdef HAVE_LIBTIRPC
 #include "xstream.h"
 #endif
 
@@ -92,6 +92,9 @@ public:
 
   bool Standard() {return standard;}
 
+  bool enabled() {return !standard || settings::verbose > 1 ||
+      interact::interactive || !settings::getSetting<bool>("quiet");}
+
   void standardEOF() {
 #if defined(HAVE_LIBREADLINE) && defined(HAVE_LIBCURSES)
     cout << endl;
@@ -510,9 +513,6 @@ public:
       return 0;
   }
 
-  bool enabled() {return !standard || settings::verbose > 1 ||
-      interact::interactive || !settings::getSetting<bool>("quiet");}
-
   void write(bool val) {*stream << (val ? "true " : "false ");}
   void write(Int val) {*stream << val;}
   void write(double val) {*stream << val;}
@@ -642,7 +642,7 @@ public:
   void writeline() {}
 };
 
-#ifdef HAVE_RPC_RPC_H
+#ifdef HAVE_LIBTIRPC
 
 class ixfile : public file {
 protected:
